.. :changelog:

History
-------

0.2.0 (2015-06-25)
------------------

* Added ``scale`` and ``quantize`` options to determine image size and quality.
* Added help texts for arguments.

0.1.1 (2015-06-09)
------------------

* Append text at the bottom of image instead of composing 2 images.

0.1.0 (2015-01-10)
------------------

* First release on PyPI.